@@ -1,4 +1,4 @@
-## ---- include = FALSE---------------------------------------------------------
+## ----include = FALSE----------------------------------------------------------
 knitr::opts_chunk$set(
   collapse = TRUE,
   comment = " "
@@ -8,7 +8,7 @@ options(cli.num_colors = 1)
 
 library(DT)
 
-## ---- include=FALSE-----------------------------------------------------------
+## ----include=FALSE------------------------------------------------------------
 # Used to control str() output later on
 
 local({
@@ -24,7 +24,7 @@ local({
   })
 })
 
-## ---- message = FALSE---------------------------------------------------------
+## ----message = FALSE----------------------------------------------------------
 library(xportr)
 library(dplyr)
 library(haven)
@@ -33,62 +33,62 @@ data("adsl_xportr", "var_spec", "dataset_spec", package = "xportr")
 colnames(var_spec)
 ADSL <- adsl_xportr
 
-## ---- eval = FALSE------------------------------------------------------------
-#  xportr_options(
-#    xportr.variable_name = "Variable",
-#    xportr.label = "Label",
-#    xportr.type_name = "Data Type",
-#    xportr.format = "Format",
-#    xportr.length = "Length",
-#    xportr.order_name = "Order"
-#  )
-#  
-#  # Or alternatively
-#  options(
-#    xportr.variable_name = "Variable",
-#    xportr.label = "Label",
-#    xportr.type_name = "Data Type",
-#    xportr.format = "Format",
-#    xportr.length = "Length",
-#    xportr.order_name = "Order"
-#  )
+## ----eval = FALSE-------------------------------------------------------------
+# xportr_options(
+#   xportr.variable_name = "Variable",
+#   xportr.label = "Label",
+#   xportr.type_name = "Data Type",
+#   xportr.format = "Format",
+#   xportr.length = "Length",
+#   xportr.order_name = "Order"
+# )
+# 
+# # Or alternatively
+# options(
+#   xportr.variable_name = "Variable",
+#   xportr.label = "Label",
+#   xportr.type_name = "Data Type",
+#   xportr.format = "Format",
+#   xportr.length = "Length",
+#   xportr.order_name = "Order"
+# )
 
-## ---- eval = FALSE------------------------------------------------------------
-#  # Default verbose is set to `none`
-#  xportr_options(
-#    xportr.format_verbose = "none",
-#    xportr.label_verbose = "none",
-#    xportr.length_verbose = "none",
-#    xportr.type_verbose = "none"
-#  )
-#  
-#  xportr_options(
-#    xportr.format_verbose = "none", # Disables any messaging, keeping the console output clean
-#    xportr.label_verbose = "message", # Sends a standard message to the console
-#    xportr.length_verbose = "warn", # Sends a warning message to the console
-#    xportr.type_verbose = "stop" # Stops execution and sends an error message to the console
-#  )
+## ----eval = FALSE-------------------------------------------------------------
+# # Default verbose is set to `none`
+# xportr_options(
+#   xportr.format_verbose = "none",
+#   xportr.label_verbose = "none",
+#   xportr.length_verbose = "none",
+#   xportr.type_verbose = "none"
+# )
+# 
+# xportr_options(
+#   xportr.format_verbose = "none", # Disables any messaging, keeping the console output clean
+#   xportr.label_verbose = "message", # Sends a standard message to the console
+#   xportr.length_verbose = "warn", # Sends a warning message to the console
+#   xportr.type_verbose = "stop" # Stops execution and sends an error message to the console
+# )
 
-## ---- eval = FALSE------------------------------------------------------------
-#  ADSL %>%
-#    xportr_type(var_spec, "ADSL", "message") %>%
-#    xportr_length(var_spec, "ADSL", verbose = "message") %>%
-#    xportr_label(var_spec, "ADSL", "message") %>%
-#    xportr_order(var_spec, "ADSL", "message") %>%
-#    xportr_format(var_spec, "ADSL") %>%
-#    xportr_df_label(dataset_spec, "ADSL") %>%
-#    xportr_write("adsl.xpt")
+## ----eval = FALSE-------------------------------------------------------------
+# ADSL %>%
+#   xportr_type(var_spec, "ADSL", "message") %>%
+#   xportr_length(var_spec, "ADSL", verbose = "message") %>%
+#   xportr_label(var_spec, "ADSL", "message") %>%
+#   xportr_order(var_spec, "ADSL", "message") %>%
+#   xportr_format(var_spec, "ADSL") %>%
+#   xportr_df_label(dataset_spec, "ADSL") %>%
+#   xportr_write("adsl.xpt")
 
-## ---- eval = FALSE------------------------------------------------------------
-#  ADSL %>%
-#    xportr_metadata(var_spec, "ADSL") %>%
-#    xportr_type() %>%
-#    xportr_length(length_source = "metadata") %>%
-#    xportr_label() %>%
-#    xportr_order() %>%
-#    xportr_format() %>%
-#    xportr_df_label(dataset_spec) %>%
-#    xportr_write("adsl.xpt")
+## ----eval = FALSE-------------------------------------------------------------
+# ADSL %>%
+#   xportr_metadata(var_spec, "ADSL") %>%
+#   xportr_type() %>%
+#   xportr_length(length_source = "metadata") %>%
+#   xportr_label() %>%
+#   xportr_order() %>%
+#   xportr_format() %>%
+#   xportr_df_label(dataset_spec) %>%
+#   xportr_write("adsl.xpt")
 
 ## -----------------------------------------------------------------------------
 var_spec <- var_spec %>%
@@ -99,7 +99,7 @@ dataset_spec <- dataset_spec %>%
   rename(label = "Description") %>%
   rename_with(tolower)
 
-## ---- echo = FALSE------------------------------------------------------------
+## ----echo = FALSE-------------------------------------------------------------
 columns2hide <- c(
   "significant digits", "mandatory", "assigned value", "codelist", "common",
   "origin", "pages", "method", "predecessor", "role", "comment",
@@ -140,30 +140,32 @@ datatable(
 adsl_fct <- ADSL %>%
   mutate(STUDYID = as_factor(STUDYID))
 
-## ---- echo = FALSE------------------------------------------------------------
+## ----echo = FALSE-------------------------------------------------------------
 adsl_glimpse <- adsl_fct %>%
   select(STUDYID, TRTSDT, TRTEDT, SCRFDT, EOSDT, FRVDT, RANDDT, DTHDT, LSTALVDT)
 
-## ---- echo = FALSE------------------------------------------------------------
+## ----echo = FALSE-------------------------------------------------------------
 glimpse(adsl_glimpse)
 
-## ---- echo = TRUE-------------------------------------------------------------
+## ----echo = TRUE--------------------------------------------------------------
 adsl_type <- xportr_type(.df = adsl_fct, metadata = var_spec, domain = "ADSL", verbose = "warn")
 
-## ---- echo = FALSE------------------------------------------------------------
+## ----echo = FALSE-------------------------------------------------------------
 adsl_type_glimpse <- adsl_type %>%
   select(STUDYID, TRTSDT, TRTEDT, SCRFDT, EOSDT, FRVDT, RANDDT, DTHDT, LSTALVDT)
 
-## ---- echo = TRUE-------------------------------------------------------------
+## ----echo = TRUE--------------------------------------------------------------
 glimpse(adsl_type_glimpse)
 
-## ---- echo = TRUE, error = TRUE-----------------------------------------------
+## ----echo = TRUE, error = TRUE------------------------------------------------
+try({
 adsl_type <- xportr_type(.df = adsl_fct, metadata = var_spec, domain = "ADSL", verbose = "stop")
+})
 
-## ---- max.height='300px', attr.output='.numberLines', echo = FALSE------------
+## ----max.height='300px', attr.output='.numberLines', echo = FALSE-------------
 str(ADSL)
 
-## ---- echo = TRUE-------------------------------------------------------------
+## ----echo = TRUE--------------------------------------------------------------
 adsl_length <- xportr_length(
   .df = ADSL,
   metadata = var_spec,
@@ -172,10 +174,11 @@ adsl_length <- xportr_length(
   length_source = "metadata"
 )
 
-## ---- max.height='300px', attr.output='.numberLines', echo = FALSE------------
+## ----max.height='300px', attr.output='.numberLines', echo = FALSE-------------
 str(adsl_length)
 
-## ---- echo = TRUE, error = TRUE-----------------------------------------------
+## ----echo = TRUE, error = TRUE------------------------------------------------
+try({
 adsl_length <- xportr_length(
   .df = ADSL,
   metadata = var_spec,
@@ -183,8 +186,9 @@ adsl_length <- xportr_length(
   verbose = "stop",
   length_source = "metadata"
 )
+})
 
-## ---- echo = TRUE-------------------------------------------------------------
+## ----echo = TRUE--------------------------------------------------------------
 var_spec_lbl <- var_spec %>%
   mutate(label = if_else(variable == "TRTSDT",
     "Length of variable label must be 40 characters or less", label
@@ -194,33 +198,38 @@ adsl_lbl <- ADSL
 
 adsl_lbl <- haven::zap_label(ADSL)
 
-## ---- max.height='300px', attr.output='.numberLines', echo = FALSE------------
+## ----max.height='300px', attr.output='.numberLines', echo = FALSE-------------
 str(adsl_lbl)
 
 ## -----------------------------------------------------------------------------
 adsl_lbl <- xportr_label(.df = adsl_lbl, metadata = var_spec_lbl, domain = "ADSL", verbose = "warn")
 
-## ---- max.height='300px', attr.output='.numberLines', echo = FALSE------------
+## ----max.height='300px', attr.output='.numberLines', echo = FALSE-------------
 str(adsl_lbl)
 
-## ---- echo = TRUE, error = TRUE-----------------------------------------------
+## ----echo = TRUE, error = TRUE------------------------------------------------
+try({
 adsl_label <- xportr_label(.df = adsl_lbl, metadata = var_spec_lbl, domain = "ADSL", verbose = "stop")
+})
 
 ## -----------------------------------------------------------------------------
 adsl_ord <- xportr_order(.df = ADSL, metadata = var_spec, domain = "ADSL", verbose = "warn")
 
-## ---- echo = TRUE, error = TRUE-----------------------------------------------
+## ----echo = TRUE, error = TRUE------------------------------------------------
+try({
 adsl_ord <- xportr_order(.df = ADSL, metadata = var_spec, domain = "ADSL", verbose = "stop")
+})
 
-## ---- echo = TRUE-------------------------------------------------------------
+## ----echo = TRUE--------------------------------------------------------------
 adsl_fmt <- ADSL %>%
   xportr_type(metadata = var_spec, domain = "ADSL", verbose = "warn") %>%
   xportr_format(metadata = var_spec, domain = "ADSL")
 
-## ---- max.height='300px', attr.output='.numberLines', echo = FALSE------------
+## ----max.height='300px', attr.output='.numberLines', echo = FALSE-------------
 str(adsl_fmt)
 
-## ---- echo = TRUE, error = TRUE-----------------------------------------------
+## ----echo = TRUE, error = TRUE------------------------------------------------
+try({
 ADSL %>%
   xportr_metadata(var_spec, "ADSL") %>%
   xportr_type() %>%
@@ -230,12 +239,16 @@ ADSL %>%
   xportr_format() %>%
   xportr_df_label(dataset_spec) %>%
   xportr_write(path = "adsl.xpt", strict_checks = FALSE)
+})
 
-## ---- echo = TRUE, error = TRUE-----------------------------------------------
+## ----echo = TRUE, error = TRUE------------------------------------------------
+try({
 ADSL %>%
   xportr_write(path = "adsl.xpt", metadata = dataset_spec, domain = "ADSL", strict_checks = TRUE)
+})
 
-## ---- echo = TRUE, error = TRUE-----------------------------------------------
+## ----echo = TRUE, error = TRUE------------------------------------------------
+try({
 var_spec_lbl <- var_spec %>%
   mutate(label = if_else(variable == "TRTSDT",
     "Length of variable label must be 40 characters or less", label
@@ -248,8 +261,10 @@ ADSL %>%
   xportr_format() %>%
   xportr_df_label(dataset_spec) %>%
   xportr_write(path = "adsl.xpt", strict_checks = TRUE)
+})
 
-## ---- echo = TRUE, error = TRUE-----------------------------------------------
+## ----echo = TRUE, error = TRUE------------------------------------------------
+try({
 xportr(
   ADSL,
   var_metadata = var_spec,
@@ -258,8 +273,10 @@ xportr(
   verbose = "none",
   path = "adsl.xpt"
 )
+})
 
-## ---- echo = TRUE, error = TRUE-----------------------------------------------
+## ----echo = TRUE, error = TRUE------------------------------------------------
+try({
 ADSL %>%
   xportr_metadata(var_spec, "ADSL") %>%
   xportr_type() %>%
@@ -269,4 +286,5 @@ ADSL %>%
   xportr_format() %>%
   xportr_df_label(dataset_spec) %>%
   xportr_write(path = "adsl.xpt", strict_checks = FALSE)
+})
 
